@@ -91,36 +91,6 @@ def _get_attributes(size_names, strip_prefixes):
   return out
 
 
-# Fields related to the internal states of actuators (i.e. with a leading
-# dimension of 'na') require special treatment.
-def _get_actuator_state_fields():
-  actuator_state_fields = []
-  for sizes_dict in sizes.array_sizes.values():
-    for field_name, dimensions in sizes_dict.items():
-      if dimensions[0] == 'na':
-        actuator_state_fields.append(field_name)
-  return frozenset(actuator_state_fields)
-
-_ACTUATOR_STATE_FIELDS = _get_actuator_state_fields()
-
-
-def _filter_stateful_actuators(physics, actuator_names):
-  """Removes any stateless actuators from the list of actuator names."""
-  if isinstance(actuator_names, str):
-    actuator_names = [actuator_names]
-
-  if physics.model.na:
-    # MuJoCo requires that stateful actuators always come after stateless
-    # actuators in the model, so we keep actuator names only if their
-    # corresponding IDs are >= to the total number of stateless actuators.
-    num_stateless_actuators = physics.model.nu - physics.model.na
-    return [
-        name for name in actuator_names
-        if physics.model.name2id(name, 'actuator') >= num_stateless_actuators]
-  else:
-    return []
-
-
 _ATTRIBUTES = {
     'actuator': _get_attributes(['na', 'nu'], strip_prefixes=['actuator']),
     'body': _get_attributes(['nbody'], strip_prefixes=['body']),
@@ -320,14 +290,7 @@ class Binding:
     try:
       index = self._array_index_cache[name]
     except KeyError:
-      # If we are indexing into a field relating to actuator internal states
-      # then we must first remove the names of any stateless actuators.
-      if name in _ACTUATOR_STATE_FIELDS:
-        named_index = _filter_stateful_actuators(
-            self._physics, self._named_index)
-      else:
-        named_index = self._named_index
-      index = named_indexer._convert_key(named_index)  # pylint: disable=protected-access
+      index = named_indexer._convert_key(self._named_index)  # pylint: disable=protected-access
       self._array_index_cache[name] = index
     return array, index
 
@@ -376,7 +339,7 @@ class Binding:
 
         if self._physics.is_dirty and not triggers_dirty:
           self._physics.forward()
-        if isinstance(index, int) and array.ndim == 1:
+        if np.issubdtype(type(index), np.integer) and array.ndim == 1:
           # Case where indexing results in a scalar.
           out = array[index]
         else:
